@@ -427,7 +427,7 @@ static bool admin_show_databases(PgSocket *admin, const char *arg)
 			host = NULL;
 
 		f_user = db->forced_user ? db->forced_user->name : NULL;
-		pktbuf_write_DataRow(buf, "ssissi",
+		pktbuf_write_DataRow(buf, "ssissii",
 				     db->name, host, db->addr.port,
 				     db->dbname, f_user,
 				     db->pool_size,
@@ -941,7 +941,7 @@ static bool admin_show_help(PgSocket *admin, const char *arg)
 		"SNOTICE", "C00000", "MConsole usage",
 		"D\n\tSHOW HELP|CONFIG|DATABASES"
 		"|POOLS|CLIENTS|SERVERS|VERSION\n"
-		"\tSHOW FDS|SOCKETS|ACTIVE_SOCKETS|LISTS|MEM\n"
+		"\tSHOW STATS|FDS|SOCKETS|ACTIVE_SOCKETS|LISTS|MEM\n"
 		"\tSET key = arg\n"
 		"\tRELOAD\n"
 		"\tPAUSE [<db>]\n"
@@ -1109,6 +1109,17 @@ bool admin_pre_login(PgSocket *client)
 		}
 	}
 
+	/*
+	 * auth_mode=any does not keep original username around,
+	 * so username based checks do not work.
+	 */
+	if (cf_auth_type == AUTH_ANY) {
+		if (cf_log_connections)
+			slog_info(client, "auth_mode=any: allowing anybody in as admin");
+		client->admin_user = 1;
+		return true;
+	}
+
 	if (strlist_contains(cf_admin_users, username)) {
 		client->admin_user = 1;
 		return true;
